@@ -29,6 +29,8 @@
 
 #define NUM_RUNS 1
 
+#undef TIMING_RUN
+
 #ifdef TIMING_RUN
 #  define d_print(a)
 #else
@@ -390,6 +392,16 @@ testIInterface (test_TestFactory   factory,
 	CORBA_free (tcs);
 }
 
+static void
+testIsA (test_TestFactory   factory, 
+	 CORBA_Environment *ev)
+{
+	g_assert (CORBA_Object_is_a (factory, "IDL:CORBA/Object:1.0", ev));
+	g_assert (ev->_major == CORBA_NO_EXCEPTION);
+	g_assert (CORBA_Object_is_a (factory, "IDL:omg.org/CORBA/Object:1.0", ev));
+	g_assert (ev->_major == CORBA_NO_EXCEPTION);
+}
+
 static void
 testFixedLengthStruct (test_TestFactory   factory, 
 		       CORBA_Environment *ev)
@@ -1249,7 +1261,7 @@ testMisc (test_TestFactory   factory,
 		/* Invoke a BasicServer method on a TestFactory */
 		foo = test_BasicServer__get_foo (factory, ev);
 		g_assert (ev->_major == CORBA_SYSTEM_EXCEPTION);
-		g_assert (!strcmp (ev->_id, "IDL:CORBA/BAD_OPERATION:1.0"));
+		g_assert (!strcmp (ev->_id, "IDL:omg.org/CORBA/BAD_OPERATION:1.0"));
 		CORBA_exception_free (ev);
 	}
 
@@ -1279,7 +1291,7 @@ testMisc (test_TestFactory   factory,
 	
 	test_BasicServer_noImplement (objref, ev);
 	g_assert (ev->_major == CORBA_SYSTEM_EXCEPTION);
-	g_assert (!strcmp (ev->_id, "IDL:CORBA/NO_IMPLEMENT:1.0"));
+	g_assert (!strcmp (ev->_id, "IDL:omg.org/CORBA/NO_IMPLEMENT:1.0"));
 	CORBA_exception_free (ev);
 
 	if (!in_proc) {
@@ -1584,6 +1596,20 @@ testPingPong (test_TestFactory   factory,
 	g_assert (!CORBA_Object_is_equivalent (
 		CORBA_OBJECT_NIL, l_objref, ev));
 
+#if 0
+	/* Test blocking bits - try to blow the remote guy's stack */
+	if (!in_proc) {
+		int i;
+
+		d_print ("Testing client limiting of stack smash on remote server\n");
+		for (i = 0; i < 10000; i++) {
+			test_PingPongServer_opOneWayCallback (r_objref, l_objref, ev);
+			g_assert (ev->_major == CORBA_NO_EXCEPTION);
+		}
+		test_PingPongServer_opRoundTrip (r_objref, ev);
+	}
+#endif
+
 	if (!in_proc) {
 		int i;
 		ORBitConnection *cnx = ORBit_small_get_connection (r_objref);
@@ -1597,7 +1623,7 @@ testPingPong (test_TestFactory   factory,
 			"the write has failed & that the connection is "
 			"now saturated ";
 		char *str;
-		gboolean broken;
+		gboolean broken = FALSE;
 
 		g_assert (cnx != NULL);
 		ORBit_connection_set_max_buffer (cnx, 10000);
@@ -1671,7 +1697,7 @@ testSegv (test_TestFactory   factory,
 		test_TestFactory_segv (factory, "do it!", ev); 
 #ifdef DO_HARDER_SEGV
 		g_assert (ev->_major == CORBA_SYSTEM_EXCEPTION);
-		g_assert (!strcmp (ev->_id, "IDL:CORBA/COMM_FAILURE:1.0"));
+		g_assert (!strcmp (ev->_id, "IDL:omg.org/CORBA/COMM_FAILURE:1.0"));
 		CORBA_exception_free (ev);
 
 		g_assert (ORBit_small_get_connection_status (factory) ==
@@ -1725,6 +1751,36 @@ test_initial_references (CORBA_ORB          orb,
 	CORBA_free (list);
 }
 
+#define TIME_TEST_RUNS 1000
+
+static void
+test_time_noop (test_TestFactory   factory, 
+		CORBA_Environment *ev)
+{
+	int i;
+	int old_flags;
+	GTimer *timer;
+
+	timer = g_timer_new ();
+	g_timer_start (timer);
+	for (i = 0; i < TIME_TEST_RUNS; i++)
+		test_TestFactory_noOp (factory, ev);
+	g_timer_stop (timer);
+	fprintf (stderr, "In proc (fast) took %g msecs\n",
+	g_timer_elapsed (timer, NULL) * 1000);
+
+	old_flags = ORBit_small_flags;
+	ORBit_small_flags &= ~ORBIT_SMALL_FAST_LOCALS;
+	g_timer_reset (timer);
+	g_timer_start (timer);
+	for (i = 0; i < TIME_TEST_RUNS; i++)
+		test_TestFactory_noOp (factory, ev);
+	g_timer_stop (timer);
+	fprintf (stderr, "In proc (slow) took %g msecs\n",
+		 g_timer_elapsed (timer, NULL) * 1000);
+	ORBit_small_flags = old_flags;
+}
+
 static void
 run_tests (test_TestFactory   factory, 
 	   CORBA_Environment *ev)
@@ -1742,6 +1798,7 @@ run_tests (test_TestFactory   factory,
 		testLongDouble (factory, ev);
 		testEnum (factory, ev);
 		testException (factory, ev);
+		testIsA (factory, ev);
 		testFixedLengthStruct (factory, ev);
 		testVariableLengthStruct (factory, ev);
 		testCompoundStruct (factory, ev);
@@ -1765,7 +1822,9 @@ run_tests (test_TestFactory   factory,
 		testContext (factory, ev);
 		testIInterface (factory, ev);
 		testMisc (factory, ev);
+#ifndef TIMING_RUN
 		testAsync (factory, ev);
+#endif
 		if (!in_proc)
 			testPingPong (factory, ev);
 #if NUM_RUNS == 1
@@ -1820,6 +1879,12 @@ main (int argc, char *argv [])
 	/* Tell linc we want a threaded ORB */
 	linc_set_threaded (TRUE);
 
+/* FIXME - make this work nicely sometime.
+	global_orb = CORBA_ORB_init (&argc, argv, "", &ev);
+	g_assert (ev._major == CORBA_NO_EXCEPTION);
+	CORBA_Object_release (global_orb, &ev);
+	g_assert (ev._major == CORBA_NO_EXCEPTION);
+*/
 	global_orb = CORBA_ORB_init (&argc, argv, "", &ev);
 	g_assert (ev._major == CORBA_NO_EXCEPTION);
 
@@ -1837,7 +1902,10 @@ main (int argc, char *argv [])
 	factory = get_server (global_orb, &ev);
 	g_assert (factory->profile_list == NULL);
 	g_assert (ORBit_object_get_connection (factory) == NULL);
+
+	test_time_noop (factory, &ev);
 	run_tests (factory, &ev);
+
 	CORBA_Object_release (factory, &ev);
 	g_assert (ev._major == CORBA_NO_EXCEPTION);
 	factory = CORBA_OBJECT_NIL;
@@ -1861,10 +1929,9 @@ main (int argc, char *argv [])
 		g_assert (ev._major == CORBA_NO_EXCEPTION);
 
 		if (CORBA_Object_non_existent (factory, &ev))
-			g_error  ("Start the server before running the client");
+			g_error  ("Can't contact the server");
 		g_assert (ev._major == CORBA_NO_EXCEPTION);
 	}
-
 	run_tests (factory, &ev);
 
 	CORBA_Object_release (factory, &ev);
